==> backup_juggler-0.2.0.tar.gz: backup_juggler-0.2.0/README.md <==
# Backup Juggler: Multiple copies of files and directories simultaneously made easy
[![Stable Version](https://img.shields.io/pypi/v/backup-juggler?label=stable)][PyPI Releases]
[![Python Versions](https://img.shields.io/pypi/pyversions/backup-juggler)][PyPI]
[![Download Stats](https://img.shields.io/pypi/dm/backup-juggler)](https://pypistats.org/packages/backup-juggler)

Backup Juggler is a command-line tool that allows you to perform multiple copies of files and directories simultaneously. The whole application is based on a command called `bj`. This command has a subcommand related to each action that the application can perform. Like `do-backups` and `get-size`.

## Installation
To install the Backup Juggler CLI, we recommend that you use `pipx`, although this is just a recommendation! You can also install the project with the manager of your choice, like `pip`. For full instalation instructions see the [instalation documentation][Tutorial]

## Documentation
The goal of this project is to help users who need to make multiple copies of files and directories simultaneously. See the [quick start guide][Documentation] or for full instructions of the current version of Backup Juggler see the [tutorial documentation][Tutorial].

## Contribute
The full [contributing documentation][Contributing Documentation] provides useful guidance, but if you have any questions or need help during the contribution process, feel free to open an [issue on the project's GitHub repository][Issue Tracker] and ask for help. We're happy to assist you.

## Resources

- [Releases][PyPI Releases]
- [Documentation]
- [Issue Tracker]

  [PyPI]: https://pypi.org/project/backup-juggler/
  [PyPI Releases]: https://pypi.org/project/backup-juggler/#history
  [Documentation]: https://backup-juggler.readthedocs.io/en/latest/
  [Tutorial]: https://backup-juggler.readthedocs.io/en/latest/tutorial/
  [Issue Tracker]: https://github.com/Raulin0/backup-juggler/issues
  [Contributing Documentation]: https://backup-juggler.readthedocs.io/en/latest/contribute/

==> backup_juggler-0.2.1.tar.gz: backup_juggler-0.2.1/README.md <==
# Backup Juggler: Multiple copies of files and directories simultaneously made easy
[![Stable Version](https://img.shields.io/pypi/v/backup-juggler?label=stable)][PyPI Releases]
[![Supported versions](https://img.shields.io/pypi/pyversions/backup-juggler)][PyPI]
[![Codecov](https://img.shields.io/codecov/c/github/raulin0/backup-juggler)](https://app.codecov.io/gh/raulin0/backup-juggler)
[![Download Stats](https://img.shields.io/pypi/dm/backup-juggler)](https://pypistats.org/packages/backup-juggler)

Backup Juggler is a command-line tool that allows you to perform multiple copies of files and directories simultaneously. The whole application is based on a command called `bj`. This command has a subcommand related to each action that the application can perform. Like `do-backups` and `get-size`.

## Installation
To install the Backup Juggler CLI, we recommend that you use [`pipx`](https://github.com/pypa/pipx), although this is just a recommendation! You can also install the project with the manager of your choice. For full installation instructions see the [installation documentation][Tutorial]

## Documentation
The goal of this project is to help users who need to make multiple copies of files and directories simultaneously. See the [quick start guide][Documentation] or for full instructions of the current version of Backup Juggler see the [tutorial documentation][Tutorial].

## Contribute
The full [contributing documentation][Contributing Documentation] provides useful guidance, but if you have any questions or need help during the contribution process, feel free to open an [issue on the project's GitHub repository][Issue Tracker] and ask for help. We're happy to assist you.

## Resources
- [Releases][PyPI Releases]
- [Documentation]
- [Issue Tracker]

  [PyPI]: https://pypi.org/project/backup-juggler/
  [PyPI Releases]: https://pypi.org/project/backup-juggler/#history
  [Documentation]: https://backup-juggler.readthedocs.io/en/latest/
  [Tutorial]: https://backup-juggler.readthedocs.io/en/latest/tutorial/
  [Issue Tracker]: https://github.com/Raulin0/backup-juggler/issues
  [Contributing Documentation]: https://backup-juggler.readthedocs.io/en/latest/contribute/
